==> zio-aws-ec2_2.13-5.17.158.4-sources.jar: zio/aws/ec2/model/ModifyInstanceMetadataOptionsRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{Integer, InstanceId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ModifyInstanceMetadataOptionsRequest(
    instanceId: InstanceId,
    httpTokens: Option[zio.aws.ec2.model.HttpTokensState] = None,
    httpPutResponseHopLimit: Option[Integer] = None,
    httpEndpoint: Option[zio.aws.ec2.model.InstanceMetadataEndpointState] =
      None,
    httpProtocolIpv6: Option[zio.aws.ec2.model.InstanceMetadataProtocolState] =
      None,
    instanceMetadataTags: Option[zio.aws.ec2.model.InstanceMetadataTagsState] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyInstanceMetadataOptionsRequest = {
    import ModifyInstanceMetadataOptionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyInstanceMetadataOptionsRequest
      .builder()
      .instanceId(InstanceId.unwrap(instanceId): java.lang.String)
      .optionallyWith(httpTokens.map(value => value.unwrap))(_.httpTokens)
      .optionallyWith(
        httpPutResponseHopLimit.map(value => value: java.lang.Integer)
      )(_.httpPutResponseHopLimit)
      .optionallyWith(httpEndpoint.map(value => value.unwrap))(_.httpEndpoint)
      .optionallyWith(httpProtocolIpv6.map(value => value.unwrap))(
        _.httpProtocolIpv6
      )
      .optionallyWith(instanceMetadataTags.map(value => value.unwrap))(
        _.instanceMetadataTags
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.ModifyInstanceMetadataOptionsRequest.ReadOnly =
    zio.aws.ec2.model.ModifyInstanceMetadataOptionsRequest.wrap(buildAwsValue())
}
object ModifyInstanceMetadataOptionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyInstanceMetadataOptionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyInstanceMetadataOptionsRequest =
      zio.aws.ec2.model.ModifyInstanceMetadataOptionsRequest(
        instanceId,
        httpTokens.map(value => value),
        httpPutResponseHopLimit.map(value => value),
        httpEndpoint.map(value => value),
        httpProtocolIpv6.map(value => value),
        instanceMetadataTags.map(value => value)
      )
    def instanceId: InstanceId
    def httpTokens: Option[zio.aws.ec2.model.HttpTokensState]
    def httpPutResponseHopLimit: Option[Integer]
    def httpEndpoint: Option[zio.aws.ec2.model.InstanceMetadataEndpointState]
    def httpProtocolIpv6
        : Option[zio.aws.ec2.model.InstanceMetadataProtocolState]
    def instanceMetadataTags
        : Option[zio.aws.ec2.model.InstanceMetadataTagsState]
    def getInstanceId: ZIO[Any, Nothing, InstanceId] = ZIO.succeed(instanceId)
    def getHttpTokens: ZIO[Any, AwsError, zio.aws.ec2.model.HttpTokensState] =
      AwsError.unwrapOptionField("httpTokens", httpTokens)
    def getHttpPutResponseHopLimit: ZIO[Any, AwsError, Integer] = AwsError
      .unwrapOptionField("httpPutResponseHopLimit", httpPutResponseHopLimit)
    def getHttpEndpoint
        : ZIO[Any, AwsError, zio.aws.ec2.model.InstanceMetadataEndpointState] =
      AwsError.unwrapOptionField("httpEndpoint", httpEndpoint)
    def getHttpProtocolIpv6
        : ZIO[Any, AwsError, zio.aws.ec2.model.InstanceMetadataProtocolState] =
      AwsError.unwrapOptionField("httpProtocolIpv6", httpProtocolIpv6)
    def getInstanceMetadataTags
        : ZIO[Any, AwsError, zio.aws.ec2.model.InstanceMetadataTagsState] =
      AwsError.unwrapOptionField("instanceMetadataTags", instanceMetadataTags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyInstanceMetadataOptionsRequest
  ) extends zio.aws.ec2.model.ModifyInstanceMetadataOptionsRequest.ReadOnly {
    override val instanceId: InstanceId =
      zio.aws.ec2.model.primitives.InstanceId(impl.instanceId())
    override val httpTokens: Option[zio.aws.ec2.model.HttpTokensState] = scala
      .Option(impl.httpTokens())
      .map(value => zio.aws.ec2.model.HttpTokensState.wrap(value))
    override val httpPutResponseHopLimit: Option[Integer] =
      scala.Option(impl.httpPutResponseHopLimit()).map(value => value: Integer)
    override val httpEndpoint
        : Option[zio.aws.ec2.model.InstanceMetadataEndpointState] = scala
      .Option(impl.httpEndpoint())
      .map(value => zio.aws.ec2.model.InstanceMetadataEndpointState.wrap(value))
    override val httpProtocolIpv6
        : Option[zio.aws.ec2.model.InstanceMetadataProtocolState] = scala
      .Option(impl.httpProtocolIpv6())
      .map(value => zio.aws.ec2.model.InstanceMetadataProtocolState.wrap(value))
    override val instanceMetadataTags
        : Option[zio.aws.ec2.model.InstanceMetadataTagsState] = scala
      .Option(impl.instanceMetadataTags())
      .map(value => zio.aws.ec2.model.InstanceMetadataTagsState.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyInstanceMetadataOptionsRequest
  ): zio.aws.ec2.model.ModifyInstanceMetadataOptionsRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.19.26.1-sources.jar: zio/aws/ec2/model/ModifyInstanceMetadataOptionsRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.{Integer, InstanceId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ModifyInstanceMetadataOptionsRequest(
    instanceId: InstanceId,
    httpTokens: Optional[zio.aws.ec2.model.HttpTokensState] = Optional.Absent,
    httpPutResponseHopLimit: Optional[Integer] = Optional.Absent,
    httpEndpoint: Optional[zio.aws.ec2.model.InstanceMetadataEndpointState] =
      Optional.Absent,
    httpProtocolIpv6: Optional[
      zio.aws.ec2.model.InstanceMetadataProtocolState
    ] = Optional.Absent,
    instanceMetadataTags: Optional[
      zio.aws.ec2.model.InstanceMetadataTagsState
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ModifyInstanceMetadataOptionsRequest = {
    import ModifyInstanceMetadataOptionsRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ModifyInstanceMetadataOptionsRequest
      .builder()
      .instanceId(InstanceId.unwrap(instanceId): java.lang.String)
      .optionallyWith(httpTokens.map(value => value.unwrap))(_.httpTokens)
      .optionallyWith(
        httpPutResponseHopLimit.map(value => value: java.lang.Integer)
      )(_.httpPutResponseHopLimit)
      .optionallyWith(httpEndpoint.map(value => value.unwrap))(_.httpEndpoint)
      .optionallyWith(httpProtocolIpv6.map(value => value.unwrap))(
        _.httpProtocolIpv6
      )
      .optionallyWith(instanceMetadataTags.map(value => value.unwrap))(
        _.instanceMetadataTags
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.ModifyInstanceMetadataOptionsRequest.ReadOnly =
    zio.aws.ec2.model.ModifyInstanceMetadataOptionsRequest.wrap(buildAwsValue())
}
object ModifyInstanceMetadataOptionsRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ModifyInstanceMetadataOptionsRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ModifyInstanceMetadataOptionsRequest =
      zio.aws.ec2.model.ModifyInstanceMetadataOptionsRequest(
        instanceId,
        httpTokens.map(value => value),
        httpPutResponseHopLimit.map(value => value),
        httpEndpoint.map(value => value),
        httpProtocolIpv6.map(value => value),
        instanceMetadataTags.map(value => value)
      )
    def instanceId: InstanceId
    def httpTokens: Optional[zio.aws.ec2.model.HttpTokensState]
    def httpPutResponseHopLimit: Optional[Integer]
    def httpEndpoint: Optional[zio.aws.ec2.model.InstanceMetadataEndpointState]
    def httpProtocolIpv6
        : Optional[zio.aws.ec2.model.InstanceMetadataProtocolState]
    def instanceMetadataTags
        : Optional[zio.aws.ec2.model.InstanceMetadataTagsState]
    def getInstanceId: ZIO[Any, Nothing, InstanceId] = ZIO.succeed(instanceId)
    def getHttpTokens: ZIO[Any, AwsError, zio.aws.ec2.model.HttpTokensState] =
      AwsError.unwrapOptionField("httpTokens", httpTokens)
    def getHttpPutResponseHopLimit: ZIO[Any, AwsError, Integer] = AwsError
      .unwrapOptionField("httpPutResponseHopLimit", httpPutResponseHopLimit)
    def getHttpEndpoint
        : ZIO[Any, AwsError, zio.aws.ec2.model.InstanceMetadataEndpointState] =
      AwsError.unwrapOptionField("httpEndpoint", httpEndpoint)
    def getHttpProtocolIpv6
        : ZIO[Any, AwsError, zio.aws.ec2.model.InstanceMetadataProtocolState] =
      AwsError.unwrapOptionField("httpProtocolIpv6", httpProtocolIpv6)
    def getInstanceMetadataTags
        : ZIO[Any, AwsError, zio.aws.ec2.model.InstanceMetadataTagsState] =
      AwsError.unwrapOptionField("instanceMetadataTags", instanceMetadataTags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ModifyInstanceMetadataOptionsRequest
  ) extends zio.aws.ec2.model.ModifyInstanceMetadataOptionsRequest.ReadOnly {
    override val instanceId: InstanceId =
      zio.aws.ec2.model.primitives.InstanceId(impl.instanceId())
    override val httpTokens: Optional[zio.aws.ec2.model.HttpTokensState] =
      zio.aws.core.internal
        .optionalFromNullable(impl.httpTokens())
        .map(value => zio.aws.ec2.model.HttpTokensState.wrap(value))
    override val httpPutResponseHopLimit: Optional[Integer] =
      zio.aws.core.internal
        .optionalFromNullable(impl.httpPutResponseHopLimit())
        .map(value => value: Integer)
    override val httpEndpoint
        : Optional[zio.aws.ec2.model.InstanceMetadataEndpointState] =
      zio.aws.core.internal
        .optionalFromNullable(impl.httpEndpoint())
        .map(value =>
          zio.aws.ec2.model.InstanceMetadataEndpointState.wrap(value)
        )
    override val httpProtocolIpv6
        : Optional[zio.aws.ec2.model.InstanceMetadataProtocolState] =
      zio.aws.core.internal
        .optionalFromNullable(impl.httpProtocolIpv6())
        .map(value =>
          zio.aws.ec2.model.InstanceMetadataProtocolState.wrap(value)
        )
    override val instanceMetadataTags
        : Optional[zio.aws.ec2.model.InstanceMetadataTagsState] =
      zio.aws.core.internal
        .optionalFromNullable(impl.instanceMetadataTags())
        .map(value => zio.aws.ec2.model.InstanceMetadataTagsState.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ModifyInstanceMetadataOptionsRequest
  ): zio.aws.ec2.model.ModifyInstanceMetadataOptionsRequest.ReadOnly =
    new Wrapper(impl)
}
